from setuptools import setup


setup(
  name='mrvaldez',
  version='0.1.0',
  py_modules=['mrvaldez'],
  author='Mark Steve Samson',
  author_email='contact@marksteve.me',
  description='Mr. Valdez has no first name',
  install_requires=[
    # What requirements?
    # Mr. Valdez requires nothing
  ],
)
